@@ -193,6 +193,7 @@ def map_github_action(config):
     config['ci_repository_url'] = net.urljoin(config.get('github_server_url'), config.get('github_repository'))
     config['ci_commit_sha'] = config.get('github_sha')
     config['ci_project_namespace'] = config.get('github_repository_owner')
+    config['ci_project_id'] = config.get('github_repository')
 
 
 def get_config(**kwargs):
@@ -294,9 +295,9 @@ def scan_keys(folder):
             try:
                 keys = subprocess.check_output(['ssh-keyscan', host], stderr=subprocess.STDOUT)
             except subprocess.CalledProcessError as error:
-                _logger.warn(('Could not scan % host, if you get any error cloning '
+                _logger.warn(('Could not scan %s host, if you get any error cloning '
                               'from this provider, please try again later'), host)
-                _logger.warn('Error was: ', error.output)
+                _logger.warn('Error was: %s', error.output)
             else:
                 for line in types.decode(keys).split('\n'):
                     clean = line.strip()
